.. _combinatorics-galois:

Galois Groups
=============

.. automodule:: sympy.combinatorics.galois

.. autoclass:: S6TransitiveSubgroups

.. autoclass:: S5TransitiveSubgroups

.. autoclass:: S4TransitiveSubgroups

.. autoclass:: S3TransitiveSubgroups

.. autoclass:: S2TransitiveSubgroups

.. autoclass:: S1TransitiveSubgroups

.. autofunction:: four_group

.. autofunction:: M20

.. autofunction:: S3_in_S6

.. autofunction:: A4_in_S6

.. autofunction:: S4m

.. autofunction:: S4p

.. autofunction:: A4xC2

.. autofunction:: S4xC2

.. autofunction:: G18

.. autofunction:: G36m

.. autofunction:: G36p

.. autofunction:: G72

.. autofunction:: PSL2F5

.. autofunction:: PGL2F5

.. autofunction:: find_transitive_subgroups_of_S6
